@@ -457,6 +457,9 @@ var NAVTREE =
     ] ],
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
+      [ "1.15 Series", "changelog.html#log_1_15", [
+        [ "Release 1.15.0", "changelog.html#log_1_15_0", null ]
+      ] ],
       [ "1.14 Series", "changelog.html#log_1_14", [
         [ "Release 1.14.0", "changelog.html#log_1_14_0", null ]
       ] ],
@@ -526,7 +529,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "additional.html",
-"commands.html#cmdrtfonly"
+"commands.html#cmdretval"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronization';
